/***************************************************************************
	file:			lcd.h
	product:	API-003
	descr:		Diese API ermoeglicht eine Ausgabe auf einem alphanumerischen LCD 
						mit einem HD44780, oder einem kompatiblen Displaycontroller. 
						Das LCD soll ueber einen 4-bit Datenbus mit dem Mikrocontroller 
						verbunden werden.
	
	date: 		10.2013 - first release

	version 	1.0
	compiler:	Keil Cx51 V9.05

	mc:				AT89C5131A
	crystal:	12MHz, 24MHz

	author: 	Viktor Schabelski info@approbe.de
	licence:	Creative Commons Lizenz
                http://www.stack2Learn.de/cc.html

**************************************************/


#ifndef _LCD_H
	#define _LCD_H

/*-----------------------------------------------------------------------------
	includes
---------------------------------------------------*/


/*-----------------------------------------------------------------------------
	constans and globals
---------------------------------------------------*/
// Error code fuer LC-Display
typedef enum _errorCodeLCD{
	LCD_SUCCESS = 0x00,
	LCD_BUSY = 0x01,
	LCD_TRANSMISSION_FAIL = 0x02
}errorCodeLCD_t;


/*-----------------------------------------------------------------------------
	api
---------------------------------------------------*/
// LCD Initialisierung
void LCD_Init(void);

// Hintergrundbeleuchtung EIN/AUS
void LCD_BackLight (unsigned char state);

// Loesche LCD Display
void LCD_ClearLCD(void);

// Setze Cursor auf Home-Position (oben links)
void LCD_ReturnHome(void);

// Gebe String auf dem LCD aus
errorCodeLCD_t LCD_PutString (unsigned char line, unsigned char column, unsigned char* pString);

//void LCD_TestCycle(void);



#endif